#include <shadow.h>

#ifndef DAY
#define DAY (24L * 60 * 60)
#endif /* DAY */

#ifndef DAY_NOW
#define DAY_NOW (time_t)time((time_t *)0) / DAY
#endif /* DAY_NOW */

static struct spwd *spwd;

static struct passwd *fix_getpwnam(u)
char   *u;
{
    struct passwd *pwd = 0;

    if ((spwd = getspnam(u)) && (pwd = getpwnam(u)))
	pwd->pw_passwd = spwd->sp_pwdp;
    return pwd;
}

#define getpwnam fix_getpwnam

extern sysv_expire(struct spwd *);
